Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(97)

Unified Diff: sdk/lib/_internal/pub_generated/lib/src/global_packages.dart

Issue 899373002: Update pub to use the VM's new bad-snapshot exit code. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Fix status and one more test Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/pub_generated/lib/src/global_packages.dart
diff --git a/sdk/lib/_internal/pub_generated/lib/src/global_packages.dart b/sdk/lib/_internal/pub_generated/lib/src/global_packages.dart
index 3dfed37924599d5a6add3a9cb3c45609e762a92b..47817a344c04ecfc1bc788affdc048991c671c56 100644
--- a/sdk/lib/_internal/pub_generated/lib/src/global_packages.dart
+++ b/sdk/lib/_internal/pub_generated/lib/src/global_packages.dart
@@ -984,9 +984,9 @@ $invocation %*
if (snapshot != null) {
batch += """
-rem The VM exits with code 255 if the snapshot version is out-of-date.
+rem The VM exits with code 253 if the snapshot version is out-of-date.
rem If it is, we need to delete it and run "pub global" manually.
-if not errorlevel 255 (
+if not errorlevel 253 (
exit /b %errorlevel%
)
@@ -1009,10 +1009,10 @@ $invocation "\$@"
if (snapshot != null) {
bash += """
# The VM exits with code 255 if the snapshot version is out-of-date.
# If it is, we need to delete it and run "pub global" manually.
exit_code=\$?
-if [ \$exit_code != 255 ]; then
+if [ \$exit_code != 253 ]; then
exit \$exit_code
fi
@@ -1009,10 +1009,10 @@ $invocation "\$@"
if (snapshot != null) {
bash += """
-# The VM exits with code 255 if the snapshot version is out-of-date.
+# The VM exits with code 253 if the snapshot version is out-of-date.
# If it is, we need to delete it and run "pub global" manually.
exit_code=\$?

Powered by Google App Engine
This is Rietveld 408576698